"""xygen
By Al Sweigart al@inventwithpython.com

A Python module that generates xy coordinates for various geometric shapes. Pronounced ex-ee-gen."""

__version__ = '0.1.0'


def line():
    pass


def lines():
    pass


def rectangle():
    pass


def square():
    pass


def circle():
    pass


def arc():
    pass


def ellipse():
    pass


def rotate2DPoint():
    pass


def rotate3DPoint():
    pass


def translate():
    pass


def scale():
    pass


def polygon():
    pass


def polygonVertices():
    pass


def grid():
    pass


def gridVertices():
    pass


def gridInterior():
    pass


def hexGrid():
    pass


def hexGridVertices():
    pass


def hexGridInterior():
    pass



class Turtle:
    pass



